@@ -35,10 +35,10 @@ class Spotify(object):
 
     if payload:
       for item in payload:
-        json_data[item] = payload[item]
+        if payload[item] != None: json_data[item] = payload[item]
     if len(kwargs) != 0:
       for kwarg in kwargs:
-        json_data[kwarg] = kwargs[kwarg]
+        if kwargs[kwarg] != None: json_data[kwarg] = kwargs[kwarg]
 
     if self.access_token:
       authorization['Authorization'] = 'Bearer %s' % self.access_token
@@ -48,7 +48,7 @@ class Spotify(object):
         endpoint += '&%s=%s' % (item, json_data[item])
       else:
         endpoint += '?%s=%s' % (item, json_data[item])
-
+    print(endpoint)
     response = await self.session.request(method, endpoint, headers=authorization)
 
     if response.status in self.error_codes:
@@ -207,24 +207,14 @@ class Spotify(object):
   async def playlists(self, limit=50, offset=0):
     return await self.send_request('GET', 'https://api.spotify.com/v1/me/playlists', limit=limit, offset=offset)
   
-  async def playlist(self, id, fields=None, types=('track',)):
+  async def playlist(self, id, types=('track')):
     id = self.get_id('playlist', id)
-    return await self.send_request('GET', 'https://api.spotify.com/v1/me/playlists/%s' % id, fields=fields, types=','.join(types))
+    return await self.send_request('GET', 'https://api.spotify.com/v1/playlists/%s' % id, types=','.join(types))
 
   async def playlist_add(self, id, items, position=None):
     id = self.get_id('playlist', id)
     items = [self.get_uri('track', i) for i in items]
-    return await self.send_request('POST', 'https://api.spotify.com/v1/me/playlists/%s/tracks' % id, payload=items, position=position)
-  
-  async def playlist_remove(self, id, items):
-    id = self.get_id('playlist', id)
-    items = [self.get_uri('track', i) for i in items]
-    data = {
-      'tracks': [{'uri': t} for t in items]}
-    }
-    return await self.send_request('POST', 'https://api.spotify.com/v1/me/playlists/%s/tracks' % id, payload=payload, position=position)
-  
-
+    return await self.send_request('POST', 'https://api.spotify.com/v1/playlists/%s/tracks' % id, uris=','.join(items), position=position)
 
   async def queue(self, track, device=None):
     uri = self.get_uri('track', track)
